pub fn retry_hint_from_etcd_error(error: &Error) -> RetryHintExpand description
Converts an etcd client error into a conservative retry hint.
pub fn retry_hint_from_etcd_error(error: &Error) -> RetryHintConverts an etcd client error into a conservative retry hint.